@@ -8,7 +8,7 @@ double lplikschlather(double *data, double *rho, double *jac,
   const int nPairs = nSite * (nSite - 1) / 2;
   double dns = 0.0;
 
-  //#pragma omp parallel for reduction(+:dns)
+#pragma omp parallel for reduction(+:dns)
   for (int currentPair=0;currentPair<nPairs;currentPair++){
 
     int i, j;
@@ -80,9 +80,8 @@ double lpliksmith(double *data, double *mahalDist, double *jac,
   const int nPairs = nSite * (nSite - 1) / 2;
   double dns = 0.0;
 
-  //#pragma omp parallel for reduction(+:dns)
+#pragma omp parallel for reduction(+:dns)
   for (int currentPair=0;currentPair<nPairs;currentPair++){
-
     int i, j;
     getSiteIndex(currentPair, nSite, &i, &j);
 
@@ -260,7 +259,7 @@ double lplikextremalt(double *data, double *rho, double df, double *jac,
   const double idf = 1 /df, dfPlus1 = df + 1;
   double dns = 0.0;
 
-  //#pragma omp parallel for reduction(+:dns)
+#pragma omp parallel for reduction(+:dns)
   for (int currentPair=0;currentPair<nPairs;currentPair++){
     int i, j;
     getSiteIndex(currentPair, nSite, &i, &j);
