@@ -142,7 +142,7 @@ void rschlatherdirect(double *coord, int *nObs, int *nSite, int *dim,
   
   /* Compute the Cholesky decomposition of the covariance matrix */
   int info = 0;
-  F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info);
+  F77_CALL(dpotrf)("U", &neffSite, covmat, &neffSite, &info FCONE);
 
   if (info != 0)
     error("error code %d from Lapack routine '%s'", info, "dpotrf");
@@ -164,7 +164,8 @@ void rschlatherdirect(double *coord, int *nObs, int *nSite, int *dim,
       for (int j=0;j<neffSite;j++)
 	gp[j] = norm_rand();
       
-      F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt);
+      F77_CALL(dtrmv)("U", "T", "N", &neffSite, covmat, &neffSite, gp, &oneInt
+		      FCONE FCONE FCONE);
 
       nKO = neffSite;
       for (int j = 0; j < neffSite; j++){
